@@ -25,12 +25,19 @@ from datameta_client_lib.model.identifier import Identifier
 from datameta_client_lib.model.meta_data_response import MetaDataResponse
 from datameta_client_lib.model.meta_data_set import MetaDataSet
 from datameta_client_lib.model.meta_data_set_response import MetaDataSetResponse
+from datameta_client_lib.model.meta_data_set_service_execution import MetaDataSetServiceExecution
 from datameta_client_lib.model.meta_datum import MetaDatum
+from datameta_client_lib.model.meta_datum_response import MetaDatumResponse
 from datameta_client_lib.model.nullable_identifier import NullableIdentifier
 from datameta_client_lib.model.password_change import PasswordChange
 from datameta_client_lib.model.register_settings_response import RegisterSettingsResponse
 from datameta_client_lib.model.registration_request import RegistrationRequest
 from datameta_client_lib.model.server_info_response import ServerInfoResponse
+from datameta_client_lib.model.service_execution import ServiceExecution
+from datameta_client_lib.model.service_request import ServiceRequest
+from datameta_client_lib.model.service_response import ServiceResponse
+from datameta_client_lib.model.service_update_request import ServiceUpdateRequest
+from datameta_client_lib.model.services import Services
 from datameta_client_lib.model.staged_files import StagedFiles
 from datameta_client_lib.model.staged_meta_data_sets import StagedMetaDataSets
 from datameta_client_lib.model.submission_request import SubmissionRequest
